@@ -1,6 +1,8 @@
+use ansi_term::Colour::Red;
 use std::fmt::Display;
 
 #[derive(Debug)]
+
 pub enum Error {
 	Io(::std::io::Error),
 	Opencv(::opencv::Error),
@@ -10,13 +12,9 @@ pub enum Error {
 impl Display for Error {
 	fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
 		match self {
-			Error::Io(io_error) => write!(f, "IO ERR: {}", io_error),
-			Error::Opencv(opencv_error) => write!(
-				f,
-				"OPENCV ERR: CODE: {}\n{}",
-				opencv_error.code, opencv_error.message
-			),
-			Error::Msg(error) => write!(f, "ERR: {}", error),
+			Error::Io(io_error) => write!(f, "IO ERR: {io_error}"),
+			Error::Opencv(opencv_error) => write!(f, "{opencv_error}"),
+			Error::Msg(error) => write!(f, "ERR: {error}"),
 		}
 	}
 }
@@ -48,3 +46,13 @@ impl From<String> for Error {
 impl std::error::Error for Error {}
 
 pub type Result<T> = std::result::Result<T, Error>;
+
+pub fn default_error_handler(handle: &mut dyn std::io::Write, error: &Error) {
+	writeln!(
+		handle,
+		"{} {}\n\nFor more information go to docs.rs/asciiframe",
+		Red.paint("error:"),
+		error
+	)
+	.unwrap();
+}
